import React, { useState, useEffect, useMemo } from 'react';
import styles from './index.less';
import { Menu, Grid, Drawer, Tooltip } from 'antd';
import { history, Helmet } from 'umi';
import routes from '../../routes';
import { MenuOutlined, PlayCircleFilled } from '@ant-design/icons';
import Footer from './footer';
const { useBreakpoint } = Grid;
const mapTree = (org) => {
  const haveChildren = Array.isArray(org.routes) && org.routes.length > 0;
  if (!org.name) return;
  const children = haveChildren
    ? {
        children: org.routes.map((i) => mapTree(i)),
      }
    : {};

  return {
    key: org.path,
    label: org.name,
    type: org.type,
    ...children,
  };
};

const MenuRender = ({ arrs, mode, activeKey }) => {
  return (
    <Menu
      mode={mode ?? 'horizontal'}
      activeKey={activeKey}
      items={arrs}
      onClick={({ item, key, keyPath, domEvent }) => {
        history.push(key);
      }}
    />
  );
};

function Layout({ children, location }) {
  const [collspan, setcollspan] = useState(false);
  const screens = useBreakpoint();
  const arrs = useMemo(() => {
    let arr = [];
    routes.map((org) => {
      if (org.name) {
        arr.push(mapTree(org));
      }
    });
    return arr;
  }, []);

  return (
    <div className={styles.container}>
      <Helmet encodeSpecialCharacters={false}>
        <html lang="en" data-direction="666" />
        <title>江苏南高智能装备创新中心有限公司</title>
      </Helmet>
      <Drawer
        open={collspan}
        title={false}
        maskClosable={true}
        onClose={() => {
          setcollspan(false);
        }}
        closable={false}
        width={260}
      >
        <MenuRender mode="inline" activeKey={location?.pathname} arrs={arrs} />
      </Drawer>
      <header>
        <div style={{ flex: 1 }}>
          {!screens.sm ? (
            <img
              src={require('@/assets/logo.svg')}
              alt=""
              style={{ width: '100%' }}
            />
          ) : (
            <img
              src={require('@/assets/logo.svg')}
              style={{ height: 52 }}
              alt=""
            />
          )}
        </div>

        <div className={styles.menu} style={{ flexShrink: 0 }}>
          {!screens.xl ? (
            <div className={styles.dll}>
              <MenuOutlined
                onClick={() => {
                  setcollspan(!collspan);
                }}
              />
              <Tooltip title="产品演示" placement="bottom">
                <PlayCircleFilled style={{ fontSize: 20, color: '#000000' }} />
              </Tooltip>
            </div>
          ) : (
            <>
              <MenuRender
                activeKey={location?.pathname}
                arrs={arrs}
              ></MenuRender>
              <div
                className="center bglight"
                style={{
                  width: 130,
                  height: 80,
                  marginRight: -24,
                  color: '#fff',
                  cursor: 'pointer',
                }}
              >
                <PlayCircleFilled
                  style={{ fontSize: 20, color: '#ffffff', marginRight: 6 }}
                />
                产品演示
              </div>
            </>
          )}
        </div>
      </header>
      <div className="content">{children}</div>
      <Footer></Footer>
    </div>
  );
}

export default Layout;
